.. Copyright (c) 2016, Johan Mabille, Sylvain Corlay, Wolf Vollprecht and Martin Renou

   Distributed under the terms of the BSD 3-Clause License.

   The full license is in the file LICENSE, distributed with this software.

xmanipulation
=============

Defined in ``xtensor/xmanipulation.hpp``

.. doxygenfunction:: xt::atleast_Nd
  :project: xtensor

.. doxygenfunction:: xt::atleast_1d
  :project: xtensor

.. doxygenfunction:: xt::atleast_2d
  :project: xtensor

.. doxygenfunction:: xt::atleast_3d
  :project: xtensor

.. doxygenfunction:: xt::expand_dims
  :project: xtensor

.. doxygenfunction:: xt::flatten
   :project: xtensor

.. doxygenfunction:: xt::flatnonzero
   :project: xtensor

.. doxygenfunction:: xt::flip
   :project: xtensor

.. doxygenfunction:: xt::ravel
   :project: xtensor

.. doxygenfunction:: xt::repeat(E&&, std::size_t, std::size_t)
   :project: xtensor

.. doxygenfunction:: xt::repeat(E&&, const std::vector<std::size_t>&, std::size_t)
   :project: xtensor

.. doxygenfunction:: xt::repeat(E&&, std::vector<std::size_t>&&, std::size_t)
   :project: xtensor

.. doxygenfunction:: xt::roll(E&&, std::ptrdiff_t)
   :project: xtensor

.. doxygenfunction:: xt::roll(E&&, std::ptrdiff_t, std::ptrdiff_t)
   :project: xtensor

.. doxygenfunction:: xt::rot90
   :project: xtensor

.. doxygenfunction:: xt::split
  :project: xtensor

.. doxygenfunction:: xt::hsplit
  :project: xtensor

.. doxygenfunction:: xt::vsplit
  :project: xtensor

.. doxygenfunction:: xt::squeeze(E&&)
  :project: xtensor

.. doxygenfunction:: xt::squeeze(E&&, S&&, Tag)
  :project: xtensor

.. doxygenfunction:: xt::transpose(E&&)
   :project: xtensor

.. doxygenfunction:: xt::transpose(E&&, S&&, Tag)
   :project: xtensor

.. doxygenfunction:: xt::trim_zeros
  :project: xtensor

